diff options
Diffstat (limited to 'tests/projects/ascendc/libs/src')
| -rw-r--r-- | tests/projects/ascendc/libs/src/lib.asc | 5 | ||||
| -rw-r--r-- | tests/projects/ascendc/libs/src/main.asc | 21 |
2 files changed, 26 insertions, 0 deletions
diff --git a/tests/projects/ascendc/libs/src/lib.asc b/tests/projects/ascendc/libs/src/lib.asc new file mode 100644 index 000000000..c0e0dad5d --- /dev/null +++ b/tests/projects/ascendc/libs/src/lib.asc @@ -0,0 +1,5 @@ +#include "kernel_operator.h" + +__global__ __vector__ void hello_world() { + AscendC::printf("[Block (%lu/%lu)]: Hello World!!!\n", AscendC::GetBlockIdx(), AscendC::GetBlockNum()); +} diff --git a/tests/projects/ascendc/libs/src/main.asc b/tests/projects/ascendc/libs/src/main.asc new file mode 100644 index 000000000..a8390825c --- /dev/null +++ b/tests/projects/ascendc/libs/src/main.asc @@ -0,0 +1,21 @@ +#include "kernel_operator.h" +#include "acl/acl.h" + +extern __global__ __vector__ void hello_world(); + +int32_t main(int argc, char const *argv[]) { + aclInit(nullptr); + int32_t deviceId = 0; + aclrtSetDevice(deviceId); + aclrtStream stream = nullptr; + aclrtCreateStream(&stream); + + constexpr uint32_t numBlocks = 8; + hello_world<<<numBlocks, nullptr, stream>>>(); + aclrtSynchronizeStream(stream); + + aclrtDestroyStream(stream); + aclrtResetDevice(deviceId); + aclFinalize(); + return 0; +} |
